middleware

package
v1.9.14 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 2, 2024 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Blacklist

func Blacklist(chats ...int64) tele.MiddlewareFunc

Blacklist returns a middleware that skips the update for users specified in the 'chats' field.

func Logger

func Logger(logger ...*log.Logger) tele.MiddlewareFunc

Logger returns a middleware that logs incoming updates. If no custom logger provided, log.Default() will be used.

func Recover

func Recover(onError ...func(error)) tele.MiddlewareFunc

Recover returns a middleware that recovers a panic happened in the handler.

func Restrict

Restrict returns a middleware that handles a list of provided chats with the logic defined by In and Out functions. If the chat is found in the Chats field, In function will be called, otherwise Out function will be called.

func Whitelist

func Whitelist(chats ...int64) tele.MiddlewareFunc

Whitelist returns a middleware that skips the update for users NOT specified in the 'chats' field.

Types

type RestrictConfig

type RestrictConfig struct {
	Chats []int64
	In    tele.HandlerFunc
	Out   tele.HandlerFunc
}

Jump to